@@ -1,4 +1,4 @@
-# Copyright (C) 1998-2003 by the Free Software Foundation, Inc.
+# Copyright (C) 1998-2009 by the Free Software Foundation, Inc.
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -12,7 +12,8 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
+# USA.
 
 """Produce listinfo page, primary web entry-point to mailing lists.
 """
@@ -87,12 +88,13 @@ def listinfo_overview(msg=''):
         mlist = MailList.MailList(name, lock=0)
         if mlist.advertised:
             if mm_cfg.VIRTUAL_HOST_OVERVIEW and \
-                   mlist.web_page_url.find(hostname) == -1:
+                   mlist.web_page_url.find('/%s/' % hostname) == -1:
                 # List is for different identity of this host - skip it.
                 continue
             else:
-                advertised.append(mlist)
-
+                advertised.append((mlist.GetScriptURL('listinfo'),
+                                   mlist.real_name,
+                                   mlist.description))
     if msg:
         greeting = FontAttr(msg, color="ff5060", size="+1")
     else:
@@ -135,10 +137,10 @@ def listinfo_overview(msg=''):
                       Bold(FontAttr(_('Description'), size='+2'))
                       ])
         highlight = 1
-        for mlist in advertised:
+        for url, real_name, description in advertised:
             table.AddRow(
-                [Link(mlist.GetScriptURL('listinfo'), Bold(mlist.real_name)),
-                 mlist.description or Italic(_('[no description available]'))])
+                [Link(url, Bold(real_name)),
+                      description or Italic(_('[no description available]'))])
             if highlight and mm_cfg.WEB_HIGHLIGHT_COLOR:
                 table.AddRowInfo(table.GetCurrentRowIndex(),
                                  bgcolor=mm_cfg.WEB_HIGHLIGHT_COLOR)
