@@ -1,4 +1,4 @@
-# Copyright (C) 2002 by the Free Software Foundation, Inc.
+# Copyright (C) 2002-2009 by the Free Software Foundation, Inc.
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -12,7 +12,8 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
+# USA.
 
 """MIME-stripping filter for Mailman.
 
@@ -90,10 +91,11 @@ def process(mlist, msg, msgdata):
     # headers.  For now we'll move the subpart's payload into the outer part,
     # and then copy over its Content-Type: and Content-Transfer-Encoding:
     # headers (any others?).
-    collapse_multipart_alternatives(msg)
-    if ctype == 'multipart/alternative':
-        firstalt = msg.get_payload(0)
-        reset_payload(msg, firstalt)
+    if mlist.collapse_alternatives:
+        collapse_multipart_alternatives(msg)
+        if ctype == 'multipart/alternative':
+            firstalt = msg.get_payload(0)
+            reset_payload(msg, firstalt)
     # If we removed some parts, make note of this
     changedp = 0
     if numparts <> len([subpart for subpart in msg.walk()]):
@@ -181,7 +183,7 @@ def collapse_multipart_alternatives(msg):
             try:
                 firstalt = subpart.get_payload(0)
                 newpayload.append(firstalt)
-            except IndexError:
+            except (IndexError, TypeError):
                 pass
         else:
             newpayload.append(subpart)
@@ -195,7 +197,7 @@ def to_plaintext(msg):
         filename = tempfile.mktemp('.html')
         fp = open(filename, 'w')
         try:
-            fp.write(subpart.get_payload())
+            fp.write(subpart.get_payload(decode=1))
             fp.close()
             cmd = os.popen(mm_cfg.HTML_TO_PLAIN_TEXT_COMMAND %
                            {'filename': filename})
@@ -209,6 +211,7 @@ def to_plaintext(msg):
             except OSError, e:
                 if e.errno <> errno.ENOENT: raise
         # Now replace the payload of the subpart and twiddle the Content-Type:
+        del subpart['content-transfer-encoding']
         subpart.set_payload(plaintext)
         subpart.set_type('text/plain')
         changedp = 1
@@ -253,4 +256,4 @@ def get_file_ext(m):
             fext = fext[1:]
         else:
             fext = ''
-    return fext
+    return fext.lower()
