@@ -1,4 +1,4 @@
-# Copyright (C) 2001-2003 by the Free Software Foundation, Inc.
+# Copyright (C) 2001-2008 by the Free Software Foundation, Inc.
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -12,7 +12,8 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
+# USA.
 
 """Old style Mailman membership adaptor.
 
@@ -201,7 +202,7 @@ class OldStyleMemberships(MemberAdaptor.MemberAdaptor):
             value = 0
         else:
             value = member
-            member = member.lower()
+        member = member.lower()
         if digest:
             self.__mlist.digest_members[member] = value
         else:
@@ -243,6 +244,8 @@ class OldStyleMemberships(MemberAdaptor.MemberAdaptor):
         password = self.__mlist.passwords.get(memberkey,
                                               Utils.MakeRandomPassword())
         lang = self.getMemberLanguage(memberkey)
+        delivery = self.__mlist.delivery_status.get(member.lower(),
+                                              (MemberAdaptor.ENABLED,0))
         # First, possibly delete the old member
         if not nodelete:
             self.removeMember(memberkey)
@@ -252,6 +255,11 @@ class OldStyleMemberships(MemberAdaptor.MemberAdaptor):
         # Set the entire options bitfield
         if flags:
             self.__mlist.user_options[newaddress.lower()] = flags
+        # If this is a straightforward address change, i.e. nodelete = 0,
+        # preserve the delivery status and time if BYUSER or BYADMIN
+        if delivery[0] in (MemberAdaptor.BYUSER, MemberAdaptor.BYADMIN)\
+          and not nodelete:
+            self.__mlist.delivery_status[newaddress.lower()] = delivery
 
     def setMemberPassword(self, memberkey, password):
         assert self.__mlist.Locked()
@@ -284,6 +292,12 @@ class OldStyleMemberships(MemberAdaptor.MemberAdaptor):
                     raise Errors.NotAMemberError, member
                 del self.__mlist.members[memberkey]
                 self.__mlist.digest_members[memberkey] = cpuser
+                # If we recently turned off digest mode and are now
+                # turning it back on, the member may be in one_last_digest.
+                # If so, remove it so the member doesn't get a dup of the
+                # next digest.
+                if self.__mlist.one_last_digest.has_key(memberkey):
+                    del self.__mlist.one_last_digest[memberkey]
             else:
                 # Be sure the list supports regular delivery
                 if not self.__mlist.nondigestable:
